| Title: | A plugin package to analyze complex survey designs with custom plugins and the 'ggsurvey' package. |
|---|---|
| Description: | A plugin package to analyze complex survey designs with custom plugins and the 'ggsurvey' package. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.11 |
| Built: | 2026-05-30 02:42:46 UTC |
| Source: | https://github.com/AlfCano/rk.ggsurvey |